@@ -498,15 +498,15 @@ class pdfCalendar():
                         path = self.defaultpath
                         showContent = False
                         if content.lower().find("first quarter")>=0 or content.find("Premier quartier")>0:
-                            ressource = join("rsc","svg","FirstQuarter.svg")
+                            ressource = abspath(join(__file__,pardir,pardir,pardir,pardir,"rsc","FirstQuarter.svg"))
                         elif content.lower().find("full moon")>=0 or content.find("Pleine lune")>0:
-                            ressource =join("rsc","svg","FullMoon_tmp2.svg")
+                            ressource =abspath(join(__file__,pardir,pardir,pardir,pardir,"rsc","FullMoon.svg"))
 
                         elif content.lower().find("last quarter")>=0 or content.find("Dernier quartier")>0:
-                            ressource = join("rsc","svg","LastQuarter.svg")
+                            ressource = abspath(join(__file__,pardir,pardir,pardir,pardir,"rsc","LastQuarter.svg"))
 
                         elif content.lower().find("new moon")>=0 or content.find("Nouvelle lune")>0:
-                            ressource = join("rsc","svg","NewMoon_tmp3.svg")
+                            ressource = abspath(join(__file__,pardir,pardir,pardir,pardir,"rsc","NewMoon.svg"))
 
                     svg_full_path = abspath(join(self.defaultpath,ressource))
                     try:
